Installation
=====

neutralNEMO can be installed using conda

.. code-block:: console

   (.venv) $ conda install -c conda-forge neutralNEMO

alternatively, neutralNEMO can be installed through pip

.. code-block:: console

   (.venv) $ pip install neutralNEMO
